@@ -35,7 +35,7 @@ static xmlXPathCompExprPtr models_xpath;
 static xmlXPathCompExprPtr layouts_xpath;
 static xmlXPathCompExprPtr option_groups_xpath;
 
-// gettext domain for translations
+/* gettext domain for translations */
 #define XKB_DOMAIN "xkeyboard-config"
 
 enum {
@@ -272,7 +272,7 @@ xkl_config_registry_foreach_in_xpath_with_param(XklConfigRegistry
 
 	if (!xkl_config_registry_is_initialized(config))
 		return;
-	snprintf(xpath_expr, sizeof xpath_expr, format, value);
+	g_snprintf(xpath_expr, sizeof xpath_expr, format, value);
 	xpath_obj = xmlXPathEval((unsigned char *) xpath_expr,
 				 xkl_config_registry_priv(config,
 							  xpath_context));
@@ -300,7 +300,8 @@ xkl_config_registry_find_object(XklConfigRegistry * config,
 	if (!xkl_config_registry_is_initialized(config))
 		return FALSE;
 
-	snprintf(xpath_expr, sizeof xpath_expr, format, arg1, pitem->name);
+	g_snprintf(xpath_expr, sizeof xpath_expr, format, arg1,
+		   pitem->name);
 	xpath_obj =
 	    xmlXPathEval((unsigned char *) xpath_expr,
 			 xkl_config_registry_priv(config, xpath_context));
@@ -890,6 +891,8 @@ xkl_config_registry_class_init(XklConfigRegistryClass * klass)
 	object_class->set_property = xkl_config_registry_set_property;
 	object_class->get_property = xkl_config_registry_get_property;
 
+	bind_textdomain_codeset (XKB_DOMAIN, "UTF-8");
+
 	engine_param_spec = g_param_spec_object("engine",
 						"Engine",
 						"XklEngine",
