@@ -1,3 +1,22 @@
+/*
+ * Copyright (C) 2002-2006 Sergey V. Udaltsov <svu@gnome.org>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
+ */
+
 #include <time.h>
 #include <stdlib.h>
 
@@ -17,6 +36,13 @@ xkl_xkb_get_groups_names(XklEngine * engine)
 						   group_names);
 }
 
+const gchar **
+xkl_xkb_get_indicators_names(XklEngine * engine)
+{
+	return (const gchar **) xkl_engine_backend(engine, XklXkb,
+						   indicator_names);
+}
+
 gint
 xkl_xkb_pause_listen(XklEngine * engine)
 {
@@ -500,6 +526,8 @@ xkl_xkb_init(XklEngine * engine)
 	    xkl_xkb_write_config_rec_to_file;
 	xkl_engine_priv(engine, get_groups_names) =
 	    xkl_xkb_get_groups_names;
+	xkl_engine_priv(engine, get_indicators_names) =
+	    xkl_xkb_get_indicators_names;
 	xkl_engine_priv(engine, get_max_num_groups) =
 	    xkl_xkb_get_max_num_groups;
 	xkl_engine_priv(engine, get_num_groups) = xkl_xkb_get_num_groups;
