@@ -1,3 +1,22 @@
+/*
+ * Copyright (C) 2002-2006 Sergey V. Udaltsov <svu@gnome.org>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
+ */
+
 #include <config.h>
 #include <stdio.h>
 #include <unistd.h>
@@ -21,12 +40,14 @@ static void
 print_usage(void)
 {
 	printf
-	    ("Usage: test_config (-g)|(-s -m <model> -l <layouts> -o <options>)|(-h)|(-ws)|(-wb)(-d <debugLevel>)(-c charset)\n");
+	    ("Usage: test_config (-g)|(-s -m <model> -l <layouts> -o <options>)|(-h)|(-ws)|(-wb)(-d <debugLevel>)\n");
 	printf("Options:\n");
 	printf("         -al - list all available layouts and variants\n");
 	printf("         -am - list all available models\n");
 	printf
 	    ("         -ao - list all available options groups and options\n");
+	printf("         -ac - list all available ISO country codes\n");
+	printf("         -ag - list all available ISO language codes\n");
 	printf
 	    ("         -g - Dump the current config, load original system settings and revert back\n");
 	printf
@@ -36,7 +57,6 @@ print_usage(void)
 	printf("         -wb - Write the source XKB config file (" PACKAGE
 	       ".xkb)\n");
 	printf("         -d - Set the debug level (by default, 0)\n");
-	printf("         -c - Set the custom charset\n");
 	printf("         -h - Show this help\n");
 }
 
@@ -66,27 +86,85 @@ static void
 print_model(XklConfigRegistry * config, const XklConfigItem * item,
 	    gpointer data)
 {
-	printf("[%s][%s][%s]\n", item->name, item->description,
-	       item->short_description);
+	gchar *vendor =
+	    (gchar *) g_object_get_data(G_OBJECT(item), XCI_PROP_VENDOR);
+	printf("[%s][%s][%s] by %s\n", item->name, item->description,
+	       item->short_description,
+	       vendor == NULL ? "unknown" : vendor);
+}
+
+static void
+print_xci(XklConfigRegistry * config, const XklConfigItem * item,
+	  gint indent)
+{
+	gchar **countries = (gchar **) g_object_get_data(G_OBJECT(item),
+							 XCI_PROP_COUNTRY_LIST);
+	gchar **languages = (gchar **) g_object_get_data(G_OBJECT(item),
+							 XCI_PROP_LANGUAGE_LIST);
+	gint i;
+	printf("%*s[%s][%s][%s]\n", indent, "", item->name,
+	       item->description, item->short_description);
+	if (countries != NULL)
+		for (i = 0; i < g_strv_length(countries); i++)
+			printf("%*s  country: [%s]\n", indent, "",
+			       countries[i]);
+	if (languages != NULL)
+		for (i = 0; i < g_strv_length(languages); i++)
+			printf("%*s  language: [%s]\n", indent, "",
+			       languages[i]);
 }
 
 static void
 print_variant(XklConfigRegistry * config, const XklConfigItem * item,
 	      gpointer data)
 {
-	printf("  [%s][%s][%s]\n", item->name,
-	       item->description, item->short_description);
+	print_xci(config, item, 2);
 }
+
 static void
 print_layout(XklConfigRegistry * config, const XklConfigItem * item,
 	     gpointer data)
 {
-	printf("[%s][%s][%s]\n", item->name, item->description,
-	       item->short_description);
+	print_xci(config, item, 0);
+
 	xkl_config_registry_foreach_layout_variant(config, item->name,
 						   print_variant, data);
 }
 
+static void
+print_iso_variant(XklConfigRegistry * config,
+		  const XklConfigItem * item,
+		  const XklConfigItem * subitem, gpointer data)
+{
+	print_xci(config, item, 2);
+	if (subitem)
+		print_xci(config, subitem, 4);
+}
+
+static void
+print_country(XklConfigRegistry * config, const XklConfigItem * item,
+	      gpointer data)
+{
+	printf("country: ");
+	print_xci(config, item, 0);
+
+	xkl_config_registry_foreach_country_variant(config, item->name,
+						    print_iso_variant,
+						    data);
+}
+
+static void
+print_language(XklConfigRegistry * config, const XklConfigItem * item,
+	       gpointer data)
+{
+	printf("language: ");
+	print_xci(config, item, 0);
+
+	xkl_config_registry_foreach_language_variant(config, item->name,
+						     print_iso_variant,
+						     data);
+}
+
 int
 main(int argc, char *const argv[])
 {
@@ -96,7 +174,6 @@ main(int argc, char *const argv[])
 	const gchar *model = NULL;
 	const gchar *layouts = NULL;
 	const gchar *options = NULL;
-	const gchar *charset = NULL;
 	int debug_level = -1;
 	int binary = 0;
 	Display *dpy;
@@ -138,9 +215,6 @@ main(int argc, char *const argv[])
 		case 'd':
 			debug_level = atoi(optarg);
 			break;
-		case 'c':
-			charset = optarg;
-			break;
 		case 'w':
 			action = ACTION_WRITE;
 			binary = ('b' == optarg[0]);
@@ -176,10 +250,6 @@ main(int argc, char *const argv[])
 		config = xkl_config_registry_get_instance(engine);
 		xkl_config_registry_load(config);
 
-		if (charset != NULL)
-			xkl_config_registry_set_custom_charset(config,
-							       charset);
-
 		xkl_debug(0, "Xklavier registry loaded\n");
 		xkl_debug(0, "Backend: [%s]\n",
 			  xkl_engine_get_backend_name(engine));
@@ -208,6 +278,14 @@ main(int argc, char *const argv[])
 				xkl_config_registry_foreach_option_group
 				    (config, print_option_group, NULL);
 				break;
+			case 'c':
+				xkl_config_registry_foreach_country
+				    (config, print_country, NULL);
+				break;
+			case 'g':
+				xkl_config_registry_foreach_language
+				    (config, print_language, NULL);
+				break;
 			default:
 				printf("Unknown list: %c\n", which_list);
 				print_usage();
